from Crypto.Cipher import AES
import base64

class aesCrypt:
    def __init__(self, key, model, iv, encode_='GBK'):  #
        self.encode_ = encode_
        self.model = {'ECB': AES.MODE_ECB, 'CBC': AES.MODE_CBC, 'CFB': AES.MODE_CFB,
                      'OFB': AES.MODE_OFB, 'CTR': AES.MODE_CTR, 'OPENPGP': AES.MODE_OPENPGP}[model]
        self.key = self.add_16(key)

        if model == 'ECB':  # 这个里创建一个aes对象
            self.aes = AES.new(self.key, self.model)
        elif model == 'CBC':
            self.aes = AES.new(self.key, self.model, iv, segment_size=128)
        elif model == 'CFB':
            self.aes = AES.new(self.key, self.model)
        elif model == 'OFB':
            self.aes = AES.new(self.key, self.model)
        elif model == 'CTR':
            self.aes = AES.new(self.key, self.model)
        elif model == 'OPENPGP':
            self.aes = AES.new(self.key, self.model)

    # 这里的密钥长度必须是16、24或32
    def add_16(self, par):
        par = par.encode(self.encode_)
        while len(par) % 16 != 0:
            par += b'\x00'
        return par

    def aesEncrypt(self, text):  # text传入的是明文
        text = self.add_16(text)
        self.encrypt_text = self.aes.encrypt(text)
        print(base64.b64encode(self.encrypt_text).decode().strip())
        try:
            return base64.b64encode(self.encrypt_text).decode().strip()
        except Exception as error:
            return error


import os
import re
import sys
import ssl
import shutil
import zipfile
import tarfile
import logging
import argparse
import platform
from os import makedirs
from os.path import join, isfile, basename
from os.path import isdir, dirname, abspath
from urllib.request import urlopen

from __init__ import __description__, __version__

logging.basicConfig(level=logging.INFO, format='%(asctime)s - %(levelname)s - %(message)s')
logger = logging.getLogger(__name__)

PY3 = sys.version_info[0] == 3

versions = sorted(['32', '64'], key=lambda v: not platform.machine().endswith(v))
os_opts = [('win', 'win', '.exe'), ('darwin', 'mac', ''), ('linux', 'linux', '')]

current_os = None
ext = ''
for o in os_opts:
    if o[0] in platform.system().lower():
        current_os = o[1]
        ext = o[2]

ssl._create_default_https_context = ssl._create_unverified_context


def main():
    """
    API test: parse command line options and run commands.
    """

    parser = argparse.ArgumentParser(description=__description__)
    parser.add_argument(
        '-v', '--version', dest='version', action='store_true',
        help="show version")

    parser.add_argument(
        '--project',
        help="Create an Seldom automation test project.")

    parser.add_argument(
        '-r',
        help="run test case")

    args = parser.parse_args()

    if args.version:
        print("version {}".format(__version__), )
        return 0

    project_name = args.project
    if project_name:
        create_scaffold(project_name)
        return 0

    run_file = args.r
    if run_file:
        logger.info("Run the python version:")
        if PY3:
            ret = os.system("python -V")
            if ret != 0:
                os.system("python3 -V")
                command = "python3 " + run_file
            else:
                command = "python " + run_file
        else:
            raise NameError("Does not support python2")
        os.system(command)
        return 0

def create_scaffold(project_name):
    """
    create scaffold with specified project name.
    """
    if os.path.isdir(project_name):
        logger.info(u"Folder {} exists, please specify a new folder name.".format(project_name))
        return

    logger.info("Start to create new test project: {}".format(project_name))
    logger.info("CWD: {}\n".format(os.getcwd()))

    def create_folder(path):
        os.makedirs(path)
        msg = "created folder: {}".format(path)
        logger.info(msg)

    def create_file(path, file_content=""):
        with open(path, 'w') as f:
            f.write(file_content)
        msg = "created file: {}".format(path)
        logger.info(msg)

    test_sample = '''import reudom


class YouTest(reudom.TestCase):

    def test_case01(self):
        """Write the test case again"""
    

if __name__ == '__main__':
    reudom.main("test_sample.py")

'''
    run_test = """import reudom


if __name__ == '__main__':
    # run test
    # reudom.main("./test_dir/")
    reudom.main("./test_dir/test_sample.py")

"""
    create_folder(project_name)
    create_folder(os.path.join(project_name, "test_dir"))
    create_folder(os.path.join(project_name, "reports"))
    create_file(os.path.join(project_name, "test_dir", "test_sample.py"), test_sample)
    create_file(os.path.join(project_name, "run.py"), run_test)

def download(url, path):
    """
    download driver file
    :param url:
    :param path:
    :return:
    """
    print('\tDownloading from: ', url)
    print('\tTo: ', path)
    file = abspath(path)
    if not isdir(dirname(file)):
        makedirs(dirname(file), exist_ok=True)
    try:
        req = urlopen(url, timeout=15)
    except Exception:
        return False
    with open(file, 'wb') as fp:
        shutil.copyfileobj(req, fp, 16 * 1024)
    return True


def extract(path, driver_pattern, out_file):
    """
    Extracts zip files, or tar.gz files.
    :param path: Path to the archive file, absolute.
    :param driver_pattern:
    :param out_file:
    :return:
    """
    path = abspath(path)
    out_file = abspath(out_file)
    if not isfile(path):
        return None
    tmp_path = join(dirname(out_file), 'tmp_dl_dir_%s' % basename(path))
    zip_ref, namelist = None, None
    if path.endswith('.zip'):
        zip_ref = zipfile.ZipFile(path, "r")
        namelist = zip_ref.namelist()
    elif path.endswith('.tar.gz'):
        zip_ref = tarfile.open(path, "r:gz")
        namelist = zip_ref.getnames()
    elif path.endswith('.tar.bz2'):
        zip_ref = tarfile.open(path, "r:bz2")
        namelist = zip_ref.getnames()
    if not zip_ref:
        return None
    ret = None
    for n in namelist:
        if re.match(driver_pattern, n):
            zip_ref.extract(n, tmp_path)
            ret = join(tmp_path, n)
    zip_ref.close()
    if ret:
        if isfile(out_file):
            os.remove(out_file)
        os.rename(ret, out_file)
        shutil.rmtree(tmp_path)
        ret = out_file
    os.remove(path)
    return ret



# coding=utf-8
import os
import time
import logging
import unittest
from .HTMLTestRunner import HTMLTestRunner

logging.basicConfig(level=logging.INFO, format='%(asctime)s - %(levelname)s - %(message)s')
logger = logging.getLogger(__name__)


reudom_str = """
                     _                 
                    | |                
  _ __ ___ _   _  __| | ___  _ __ ___  
 | '__/ _ | | | |/ _` |/ _ \| '_ ` _ \ 
 | | |  __| |_| | (_| | (_) | | | | | |
 |_|  \___|\__,_|\__,_|\___/|_| |_| |_|                             
 --------------------------------------
                            @itest.info
"""

def main(path=None,
         title="Reudom Test Report",
         description="Test case execution",
         debug=False,
         rerun=0,
         save_last_run=False):
    """
    runner test case
    :param path:
    :param title:
    :param description:
    :param debug:
    :param rerun:
    :param save_last_run:
    :return:
    """

    if path is None:
        suits = unittest.defaultTestLoader.discover(os.getcwd())
    else:
        if len(path) > 3:
            if path[-3:] == ".py":
                if "/" in path:
                    path_list = path.split("/")
                    path_dir = path.replace(path_list[-1], "")
                    suits = unittest.defaultTestLoader.discover(path_dir, pattern=path_list[-1])
                else:
                    suits = unittest.defaultTestLoader.discover(os.getcwd(), pattern=path)
            else:
                suits = unittest.defaultTestLoader.discover(path)
        else:
            suits = unittest.defaultTestLoader.discover(path)

    if debug is False:
        for filename in os.listdir(os.getcwd()):
            if filename == "reports":
                break
        else:
            os.mkdir(os.path.join(os.getcwd(), "reports"))

        now = time.strftime("%Y_%m_%d_%H_%M_%S")
        report = os.path.join(os.getcwd(), "reports", now + "_result.html")

        with(open(report, 'wb')) as fp:
            runner = HTMLTestRunner(stream=fp, title=title, description=description)
            print(reudom_str)
            runner.run(suits, rerun=rerun, save_last_run=save_last_run)
        print("generated html file: file:///{}".format(report))
    else:
        runner = unittest.TextTestRunner(verbosity=2)
        logger.info("reudom run test 🛫🛫!")
        print(reudom_str)
        runner.run(suits)
        logger.info("End of the test 🔚!")


if __name__ == '__main__':
    main()




import unittest


class TestCase(unittest.TestCase):

    @classmethod
    def setUpClass(cls):
        """Hook method for setting up class fixture before running tests in the class."""

    @classmethod
    def tearDownClass(cls):
        """Hook method for deconstructing the class fixture after running all tests in the class."""


#!/usr/bin/python
#
# Licensed to the Software Freedom Conservancy (SFC) under one
# or more contributor license agreements.  See the NOTICE file
# distributed with this work for additional information
# regarding copyright ownership.  The SFC licenses this file
# to you under the Apache License, Version 2.0 (the
# "License"); you may not use this file except in compliance
# with the License.  You may obtain a copy of the License at
#
#   http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing,
# software distributed under the License is distributed on an
# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
# KIND, either express or implied.  See the License for the
# specific language governing permissions and limitations
# under the License.

from .running.test_runner import main
from .case import TestCase
from .testdata import ddt, ddt_class
from .skip import skip
from requests import request
from requests import *
from unittest import TestCase
from Crypto.Cipher import AES
from Crypto import *
from Crypto import Cipher, Hash, Protocol, PublicKey, Random, SelfTest, Signature, Util
from .CryptoAES.aesEncrypt import aesCrypt
__author__ = "Barry"

__version__ = "1.1.4"

__description__ = "Automated testing framework based on requests and unittest interface."

